@@ -826,9 +826,6 @@ class ValidatorMixin:
         if row_reporting_offset:
             offset_ret = defaultdict(dict)
             for tabname, report in ret.items():
-                is_units = len(self.getunits(tabname)) > 0
-                # iterate over each rows
-                _data = self._data[tabname]
                 for index, _ in report.items():
                     try:
                         (colname, rownb) = index
@@ -840,12 +837,9 @@ class ValidatorMixin:
                     else:
                         msgs = report[(colname, rownb)]
                         # row_reporting_offset == "spreadsheet"
-                        reported_rownb = _data.loc[rownb]["__rownb_xlsx"]
-                        if row_reporting_offset == "data":
-                            if is_units:
-                                reported_rownb -= 2
-                            else:
-                                reported_rownb -= 1
+                        reported_rownb = self.get_reported_rownb(
+                            tabname, rownb, row_reporting_offset=row_reporting_offset
+                        )
                         offset_ret[tabname][(colname, reported_rownb)] = msgs
             ret = offset_ret
         if readonly:
@@ -853,6 +847,19 @@ class ValidatorMixin:
             self._data = {tabname: df.copy() for tabname, df in self._raw_data.items()}
         return dict(ret)
 
+    def get_reported_rownb(self, tabname, ix, row_reporting_offset="data"):
+        """return user-friendly row index"""
+        if not row_reporting_offset:
+            return ix
+        reported_rownb = self._data[tabname].loc[ix]["__rownb_xlsx"]
+        if row_reporting_offset == "data":
+            is_units = len(self.getunits(tabname)) > 0
+            if is_units:
+                reported_rownb -= 2
+            else:
+                reported_rownb -= 1
+        return reported_rownb
+
     def dump_template(self):
         """return list of columns ready to be dumped as XLSX template"""
         dic = defaultdict(dict)
